@@ -1,8 +1,7 @@
 //! Limited queue implementation
 //!
 
-
-use std::convert::TryInto;
+use std::{convert::TryInto, fmt::Debug};
 
 use crossbeam_queue::ArrayQueue;
 use tokio::sync::Semaphore;
@@ -24,6 +23,17 @@ pub struct Queue<T> {
     available: Available,
 }
 
+impl<T> Debug for Queue<T> {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("Queue")
+            .field("queue", &self.queue)
+            .field("push_semaphore", &self.push_semaphore)
+            .field("pop_semaphore", &self.pop_semaphore)
+            .field("available", &self.available)
+            .finish()
+    }
+}
+
 impl<T> Queue<T> {
     /// Create new empty queue
     pub fn new(max_size: usize) -> Self {
@@ -85,6 +95,10 @@ impl<T> Queue<T> {
     pub fn len(&self) -> usize {
         self.queue.len()
     }
+    /// Returns `true` if the queue is empty.
+    pub fn is_empty(&self) -> bool {
+        self.queue.is_empty()
+    }
     /// The number of available items in the queue. If there are no
     /// items in the queue this number can become negative and stores the
     /// number of futures waiting for an item.
