@@ -41,4 +41,11 @@ mod tests {
         }
         assert_eq!(queue.len(), 0);
     }
+
+    #[test]
+    fn test_debug() {
+        struct NoDebug {}
+        let queue: Queue<NoDebug> = Queue::new(1);
+        format!("{:?}", queue);
+    }
 }
